@@ -3,15 +3,16 @@ Main interface for servicediscovery service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.servicediscovery import (
+    from mypy_boto3_servicediscovery import (
         Client,
         ListInstancesPaginator,
         ListNamespacesPaginator,
         ListOperationsPaginator,
         ListServicesPaginator,
         ServiceDiscoveryClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -22,11 +23,9 @@ Usage::
     list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
     list_operations_paginator: ListOperationsPaginator = client.get_paginator("list_operations")
     list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
+    ```
 """
-from mypy_boto3_servicediscovery.client import (
-    ServiceDiscoveryClient as Client,
-    ServiceDiscoveryClient,
-)
+from mypy_boto3_servicediscovery.client import ServiceDiscoveryClient
 from mypy_boto3_servicediscovery.paginator import (
     ListInstancesPaginator,
     ListNamespacesPaginator,
@@ -34,6 +33,8 @@ from mypy_boto3_servicediscovery.paginator import (
     ListServicesPaginator,
 )
 
+Client = ServiceDiscoveryClient
+
 
 __all__ = (
     "Client",
